@@ -1,10 +1,11 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
 use crate::typeref::*;
-use ahash::CallHasher;
 use associative_cache::replacement::RoundRobinReplacement;
 use associative_cache::*;
 use once_cell::unsync::OnceCell;
+use std::hash::BuildHasher;
+use std::hash::Hasher;
 use std::os::raw::c_void;
 
 #[repr(transparent)]
@@ -36,10 +37,12 @@ impl Drop for CachedKey {
 }
 
 pub type KeyMap =
-    AssociativeCache<u64, CachedKey, Capacity512, HashDirectMapped, RoundRobinReplacement>;
+    AssociativeCache<u64, CachedKey, Capacity1024, HashDirectMapped, RoundRobinReplacement>;
 
 pub static mut KEY_MAP: OnceCell<KeyMap> = OnceCell::new();
 
 pub fn cache_hash(key: &[u8]) -> u64 {
-    <[u8]>::get_hash(&key, unsafe { &*HASH_BUILDER })
+    let mut hasher = unsafe { (*HASH_BUILDER).build_hasher() };
+    hasher.write(key);
+    hasher.finish()
 }
