@@ -8,8 +8,8 @@ use crate::serialize::error::*;
 use crate::serialize::serializer::pyobject_to_obtype;
 use crate::serialize::serializer::*;
 use crate::serialize::uuid::*;
+use crate::str::*;
 use crate::typeref::*;
-use crate::unicode::*;
 use compact_str::CompactString;
 use serde::ser::{Serialize, SerializeMap, Serializer};
 use smallvec::SmallVec;
