@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
-use crate::exc::*;
+use crate::serialize::error::*;
 use serde::ser::{Serialize, Serializer};
 
 // https://tools.ietf.org/html/rfc7159#section-6
@@ -19,15 +19,19 @@ impl IntSerializer {
     }
 }
 
-impl<'p> Serialize for IntSerializer {
+impl Serialize for IntSerializer {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
         S: Serializer,
     {
         let val = ffi!(PyLong_AsLongLong(self.ptr));
-        if unlikely!(val == -1 && !ffi!(PyErr_Occurred()).is_null()) {
-            UIntSerializer::new(self.ptr).serialize(serializer)
+        if val == -1 {
+            if unlikely!(!ffi!(PyErr_Occurred()).is_null()) {
+                UIntSerializer::new(self.ptr).serialize(serializer)
+            } else {
+                serializer.serialize_i64(val)
+            }
         } else {
             serializer.serialize_i64(val)
         }
@@ -45,8 +49,7 @@ impl UIntSerializer {
     }
 }
 
-impl<'p> Serialize for UIntSerializer {
-    #[cold]
+impl Serialize for UIntSerializer {
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -54,10 +57,15 @@ impl<'p> Serialize for UIntSerializer {
     {
         ffi!(PyErr_Clear());
         let val = ffi!(PyLong_AsUnsignedLongLong(self.ptr));
-        if unlikely!(val == u64::MAX && !ffi!(PyErr_Occurred()).is_null()) {
-            err!(SerializeError::Integer64Bits)
+        if unlikely!(val == u64::MAX) {
+            if ffi!(PyErr_Occurred()).is_null() {
+                serializer.serialize_u64(val)
+            } else {
+                err!(SerializeError::Integer64Bits)
+            }
+        } else {
+            serializer.serialize_u64(val)
         }
-        serializer.serialize_u64(val)
     }
 }
 
@@ -72,7 +80,7 @@ impl Int53Serializer {
     }
 }
 
-impl<'p> Serialize for Int53Serializer {
+impl Serialize for Int53Serializer {
     #[cold]
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -80,11 +88,16 @@ impl<'p> Serialize for Int53Serializer {
         S: Serializer,
     {
         let val = ffi!(PyLong_AsLongLong(self.ptr));
-        if unlikely!(val == -1 && !ffi!(PyErr_Occurred()).is_null())
-            || (val > STRICT_INT_MAX || val < STRICT_INT_MIN)
-        {
+        if unlikely!(val == -1) {
+            if ffi!(PyErr_Occurred()).is_null() {
+                serializer.serialize_i64(val)
+            } else {
+                err!(SerializeError::Integer53Bits)
+            }
+        } else if !(STRICT_INT_MIN..=STRICT_INT_MAX).contains(&val) {
             err!(SerializeError::Integer53Bits)
+        } else {
+            serializer.serialize_i64(val)
         }
-        serializer.serialize_i64(val)
     }
 }
