@@ -7,7 +7,9 @@ mod datetimelike;
 mod default;
 mod dict;
 mod error;
+mod float;
 mod int;
+mod json;
 mod list;
 mod numpy;
 mod pyenum;
