@@ -1,8 +1,8 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
 use crate::ffi::PyBytesObject;
+use crate::serialize::json::WriteExt;
 use pyo3_ffi::*;
-use serde_json::WriteExt;
 use std::os::raw::c_char;
 use std::ptr::NonNull;
 
@@ -44,6 +44,7 @@ impl BytesWriter {
         }
     }
 
+    #[inline]
     pub fn resize(&mut self, len: usize) {
         self.cap = len;
         unsafe {
@@ -54,6 +55,7 @@ impl BytesWriter {
         }
     }
 
+    #[cold]
     #[inline(never)]
     fn grow(&mut self, len: usize) {
         let mut cap = self.cap;
@@ -93,6 +95,24 @@ impl std::io::Write for BytesWriter {
 }
 
 impl WriteExt for &mut BytesWriter {
+    #[inline(always)]
+    fn as_mut_buffer_ptr(&mut self) -> *mut u8 {
+        self.buffer_ptr()
+    }
+
+    #[inline(always)]
+    fn reserve(&mut self, len: usize) {
+        let end_length = self.len + len;
+        if unlikely!(end_length > self.cap) {
+            self.grow(end_length);
+        }
+    }
+
+    #[inline(always)]
+    fn set_written(&mut self, len: usize) {
+        self.len += len;
+    }
+
     fn write_str(&mut self, val: &str) -> Result<(), std::io::Error> {
         let to_write = val.len();
         let end_length = self.len + to_write + 2;
@@ -109,15 +129,34 @@ impl WriteExt for &mut BytesWriter {
         Ok(())
     }
 
-    fn write_indent(&mut self, len: usize) -> Result<(), std::io::Error> {
-        let end_length = self.len + len;
-        if unlikely!(end_length > self.cap) {
-            self.grow(end_length);
-        }
+    unsafe fn write_reserved_fragment(
+        &mut self,
+        val: &[u8],
+    ) -> std::result::Result<(), std::io::Error> {
+        let to_write = val.len();
+        unsafe {
+            std::ptr::copy_nonoverlapping(val.as_ptr() as *const u8, self.buffer_ptr(), to_write);
+        };
+        self.len += to_write;
+        Ok(())
+    }
+
+    #[inline(always)]
+    unsafe fn write_reserved_punctuation(
+        &mut self,
+        val: u8,
+    ) -> std::result::Result<(), std::io::Error> {
+        unsafe { std::ptr::write(self.buffer_ptr(), val) };
+        self.len += 1;
+        Ok(())
+    }
+
+    #[inline(always)]
+    unsafe fn write_reserved_indent(&mut self, len: usize) -> Result<(), std::io::Error> {
         unsafe {
             std::ptr::write_bytes(self.buffer_ptr(), b' ', len);
         };
-        self.len = end_length;
+        self.len += len;
         Ok(())
     }
 }
